@@ -52,13 +52,6 @@
 
 #define SYSCALL(call) while (((call) == -1) && (errno == EINTR))
 
-struct SynapticsHwInfo {
-    unsigned int model_id;		    /* Model-ID */
-    unsigned int capabilities;		    /* Capabilities */
-    unsigned int ext_cap;		    /* Extended Capabilities */
-    unsigned int identity;		    /* Identification */
-};
-
 /*
  * Identify Touchpad
  * See also the SYN_ID_* macros
@@ -79,7 +72,7 @@ psm_synaptics_identify(int fd, synapticshw_t *ident)
 #define PSM_LEVEL_NATIVE	2
 
 static Bool
-PSMQueryIsSynaptics(LocalDevicePtr local)
+PSMQueryIsSynaptics(InputInfoPtr pInfo)
 {
     int ret;
     int level = PSM_LEVEL_NATIVE;
@@ -89,28 +82,28 @@ PSMQueryIsSynaptics(LocalDevicePtr local)
      * Otherwise HWINFO will not return the right id
      * And we will need native mode anyway ...
      */
-    SYSCALL(ret = ioctl(local->fd, MOUSE_SETLEVEL, &level));
+    SYSCALL(ret = ioctl(pInfo->fd, MOUSE_SETLEVEL, &level));
     if (ret != 0) {
-	xf86Msg(X_ERROR, "%s Can't set native mode\n", local->name);
+	xf86IDrvMsg(pInfo, X_ERROR, "%s Can't set native mode\n", pInfo->name);
 	return FALSE;
     }
-    SYSCALL(ret = ioctl(local->fd, MOUSE_GETHWINFO, &mhw));
+    SYSCALL(ret = ioctl(pInfo->fd, MOUSE_GETHWINFO, &mhw));
     if (ret != 0) {
-	xf86Msg(X_ERROR, "%s Can't get hardware info\n", local->name);
+	xf86IDrvMsg(pInfo, X_ERROR, "%s Can't get hardware info\n", pInfo->name);
 	return FALSE;
     }
 
     if (mhw.model == MOUSE_MODEL_SYNAPTICS) {
 	return TRUE;
     } else {
-	xf86Msg(X_ERROR, "%s Found no Synaptics, found Mouse model %d instead\n",
-		local->name, mhw.model);
+	xf86IDrvMsg(pInfo, X_ERROR, "%s Found no Synaptics, found Mouse model %d instead\n",
+		pInfo->name, mhw.model);
 	return FALSE;
     }
 }
 
 static void
-convert_hw_info(const synapticshw_t *psm_ident, struct SynapticsHwInfo *synhw)
+convert_hw_info(const synapticshw_t *psm_ident, struct PS2SynapticsHwInfo *synhw)
 {
     memset(synhw, 0, sizeof(*synhw));
     synhw->model_id = ((psm_ident->infoRot180 << 23) |
@@ -134,45 +127,39 @@ convert_hw_info(const synapticshw_t *psm_ident, struct SynapticsHwInfo *synhw)
 }
 
 static Bool
-PSMQueryHardware(LocalDevicePtr local)
+PSMQueryHardware(InputInfoPtr pInfo)
 {
     synapticshw_t psm_ident;
-    struct SynapticsHwInfo *synhw;
+    struct PS2SynapticsHwInfo *synhw;
     SynapticsPrivate *priv;
 
-    priv = (SynapticsPrivate *)local->private;
+    priv = (SynapticsPrivate *)pInfo->private;
 
     if(!priv->proto_data)
-        priv->proto_data = xcalloc(1, sizeof(struct SynapticsHwInfo));
-    synhw = (struct SynapticsHwInfo*)priv->proto_data;
+        priv->proto_data = calloc(1, sizeof(struct PS2SynapticsHwInfo));
+    synhw = (struct PS2SynapticsHwInfo*)priv->proto_data;
 
     /* is the synaptics touchpad active? */
-    if (!PSMQueryIsSynaptics(local))
+    if (!PSMQueryIsSynaptics(pInfo))
 	return FALSE;
 
-    xf86Msg(X_PROBED, "%s synaptics touchpad found\n", local->name);
+    xf86IDrvMsg(pInfo, X_PROBED, "synaptics touchpad found\n");
 
-    if (!psm_synaptics_identify(local->fd, &psm_ident))
+    if (!psm_synaptics_identify(pInfo->fd, &psm_ident))
 	return FALSE;
 
     convert_hw_info(&psm_ident, synhw);
 
-    ps2_print_ident(synhw);
+    ps2_print_ident(pInfo, synhw);
 
     return TRUE;
 }
 
 static Bool
-PSMReadHwState(LocalDevicePtr local,
-	       struct SynapticsProtocolOperations *proto_ops,
+PSMReadHwState(InputInfoPtr pInfo,
 	       struct CommData *comm, struct SynapticsHwState *hwRet)
 {
-    return psaux_proto_operations.ReadHwState(local, proto_ops, comm, hwRet);
-}
-
-static Bool PSMAutoDevProbe(LocalDevicePtr local)
-{
-    return FALSE;
+    return PS2ReadHwStateProto(pInfo, &psm_proto_operations, comm, hwRet);
 }
 
 struct SynapticsProtocolOperations psm_proto_operations = {
@@ -180,6 +167,6 @@ struct SynapticsProtocolOperations psm_proto_operations = {
     NULL,
     PSMQueryHardware,
     PSMReadHwState,
-    PSMAutoDevProbe,
-    SynapticsDefaultDimensions
+    NULL,
+    NULL
 };
